Package: RMariaDB
Title: Database Interface and MariaDB Driver
Version: 1.3.5
Authors@R: c(
    person("Kirill", "Müller", , "kirill@cynkra.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-1416-3412")),
    person("Jeroen", "Ooms", role = "aut",
           comment = c(ORCID = "0000-0002-4035-0289")),
    person("David", "James", role = "aut"),
    person("Saikat", "DebRoy", role = "aut"),
    person("Hadley", "Wickham", role = "aut"),
    person("Jeffrey", "Horner", role = "aut"),
    person("R Consortium", role = "fnd"),
    person("RStudio", role = "cph")
  )
Description: Implements a DBI-compliant interface to MariaDB
    (<https://mariadb.org/>) and MySQL (<https://www.mysql.com/>)
    databases.
License: MIT + file LICENSE
URL: https://rmariadb.r-dbi.org, https://github.com/r-dbi/RMariaDB,
        https://downloads.mariadb.org/connector-c/
BugReports: https://github.com/r-dbi/RMariaDB/issues
Depends: R (>= 2.8.0)
Imports: bit64, blob, DBI (>= 1.1.3), hms (>= 0.5.0), lubridate,
        methods, rlang
Suggests: DBItest (>= 1.7.2.9001), decor, readr, rprojroot, testthat
        (>= 3.0.0), withr
LinkingTo: cpp11
Config/Needs/website: r-dbi/dbitemplate
Config/autostyle/scope: line_breaks
Config/autostyle/strict: false
Config/testthat/edition: 3
Encoding: UTF-8
NeedsCompilation: yes
RoxygenNote: 7.3.3.9000
SystemRequirements: libmariadb-client-lgpl-dev or libmariadb-dev or
        libmysqlclient-dev, with libssl-dev (deb),
        mariadb-connector-c-devel or mariadb-devel (rpm),
        mariadb-connector-c or mysql-connector-c (brew)
Collate: 'MariaDBConnection.R' 'MariaDBDriver.R' 'MariaDBResult.R'
        'RMariaDB-package.R' 'coerce.R' 'compatRowNames.R' 'connect.R'
        'cpp11.R' 'dbAppendTable_MariaDBConnection.R'
        'dbBegin_MariaDBConnection.R' 'dbBind_MariaDBResult.R'
        'dbClearResult_MariaDBResult.R' 'dbColumnInfo_MariaDBResult.R'
        'dbCommit_MariaDBConnection.R' 'dbConnect_MariaDBDriver.R'
        'dbDataType_MariaDBConnection.R' 'dbDataType_MariaDBDriver.R'
        'dbDisconnect_MariaDBConnection.R'
        'dbExistsTable_MariaDBConnection_character.R'
        'dbFetch_MariaDBResult.R' 'dbGetInfo_MariaDBConnection.R'
        'dbGetInfo_MariaDBDriver.R' 'dbGetRowCount_MariaDBResult.R'
        'dbGetRowsAffected_MariaDBResult.R'
        'dbGetStatement_MariaDBResult.R'
        'dbHasCompleted_MariaDBResult.R'
        'dbIsValid_MariaDBConnection.R' 'dbIsValid_MariaDBDriver.R'
        'dbIsValid_MariaDBResult.R'
        'dbListObjects_MariaDBConnection_ANY.R'
        'dbListTables_MariaDBConnection.R'
        'dbQuoteIdentifier_MariaDBConnection_Id.R'
        'dbQuoteIdentifier_MariaDBConnection_SQL.R'
        'dbQuoteIdentifier_MariaDBConnection_character.R'
        'dbQuoteLiteral_MariaDBConnection.R'
        'dbQuoteLiteral_MySQLConnection.R'
        'dbQuoteString_MariaDBConnection_SQL.R'
        'dbQuoteString_MariaDBConnection_character.R'
        'dbReadTable_MariaDBConnection_character.R'
        'dbRemoveTable_MariaDBConnection_character.R'
        'dbRollback_MariaDBConnection.R'
        'dbSendQuery_MariaDBConnection_character.R'
        'dbSendStatement_MariaDBConnection_character.R'
        'dbUnloadDriver_MariaDBDriver.R'
        'dbUnquoteIdentifier_MariaDBConnection_SQL.R'
        'dbWriteTable_MariaDBConnection_character_character.R'
        'dbWriteTable_MariaDBConnection_character_data.frame.R'
        'default.R' 'export.R' 'query.R' 'quote-mysql.R' 'quote.R'
        'show_MariaDBConnection.R' 'sqlData_MariaDBConnection.R'
        'table.R' 'transaction.R' 'utils.R' 'zzz.R'
Packaged: 2026-02-05 19:48:36 UTC; kirill
Author: Kirill Müller [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1416-3412>),
  Jeroen Ooms [aut] (ORCID: <https://orcid.org/0000-0002-4035-0289>),
  David James [aut],
  Saikat DebRoy [aut],
  Hadley Wickham [aut],
  Jeffrey Horner [aut],
  R Consortium [fnd],
  RStudio [cph]
Maintainer: Kirill Müller <kirill@cynkra.com>
Repository: CRAN
Date/Publication: 2026-02-06 06:40:54 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 21:41:58 UTC; unix
Archs: RMariaDB.so.dSYM
