# Generated by roxygen2: do not edit by hand

S3method(format,MariaDBConnection)
export(CLIENT_COMPRESS)
export(CLIENT_CONNECT_WITH_DB)
export(CLIENT_FOUND_ROWS)
export(CLIENT_IGNORE_SIGPIPE)
export(CLIENT_IGNORE_SPACE)
export(CLIENT_INTERACTIVE)
export(CLIENT_LOCAL_FILES)
export(CLIENT_LONG_FLAG)
export(CLIENT_LONG_PASSWORD)
export(CLIENT_MULTI_RESULTS)
export(CLIENT_MULTI_STATEMENTS)
export(CLIENT_NO_SCHEMA)
export(CLIENT_ODBC)
export(CLIENT_PROTOCOL_41)
export(CLIENT_RESERVED)
export(CLIENT_RESERVED2)
export(CLIENT_SSL)
export(CLIENT_SSL_VERIFY_SERVER_CERT)
export(CLIENT_TRANSACTIONS)
export(Id)
export(MariaDB)
export(mariadbClientLibraryVersions)
export(mariadbDefault)
export(mariadbHasDefault)
exportClasses(MariaDBConnection)
exportClasses(MariaDBDriver)
exportClasses(MariaDBResult)
exportClasses(MySQLConnection)
exportMethods(dbAppendTable)
exportMethods(dbBegin)
exportMethods(dbBind)
exportMethods(dbCanConnect)
exportMethods(dbClearResult)
exportMethods(dbColumnInfo)
exportMethods(dbCommit)
exportMethods(dbConnect)
exportMethods(dbCreateTable)
exportMethods(dbDataType)
exportMethods(dbDisconnect)
exportMethods(dbDriver)
exportMethods(dbExecute)
exportMethods(dbExistsTable)
exportMethods(dbFetch)
exportMethods(dbGetInfo)
exportMethods(dbGetQuery)
exportMethods(dbGetRowCount)
exportMethods(dbGetRowsAffected)
exportMethods(dbGetStatement)
exportMethods(dbHasCompleted)
exportMethods(dbIsReadOnly)
exportMethods(dbIsValid)
exportMethods(dbListFields)
exportMethods(dbListObjects)
exportMethods(dbListResults)
exportMethods(dbListTables)
exportMethods(dbQuoteIdentifier)
exportMethods(dbQuoteLiteral)
exportMethods(dbQuoteString)
exportMethods(dbReadTable)
exportMethods(dbRemoveTable)
exportMethods(dbRollback)
exportMethods(dbSendQuery)
exportMethods(dbSendStatement)
exportMethods(dbUnloadDriver)
exportMethods(dbUnquoteIdentifier)
exportMethods(dbWithTransaction)
exportMethods(dbWriteTable)
exportMethods(show)
import(DBI)
import(methods)
importFrom(DBI,Id)
importFrom(bit64,integer64)
importFrom(bit64,is.integer64)
importFrom(hms,hms)
importFrom(utils,read.table)
importFrom(utils,write.table)
useDynLib(RMariaDB, .registration = TRUE)
