# Generated by cpp11: do not edit by hand

connection_create <- function(host, user, password, db, port, unix_socket, client_flag, group, default_file, ssl_key, ssl_cert, ssl_ca, ssl_capath, ssl_cipher, timeout, reconnect) {
  .Call(`_RMariaDB_connection_create`, host, user, password, db, port, unix_socket, client_flag, group, default_file, ssl_key, ssl_cert, ssl_ca, ssl_capath, ssl_cipher, timeout, reconnect)
}

connection_valid <- function(con_) {
  .Call(`_RMariaDB_connection_valid`, con_)
}

connection_release <- function(con_) {
  invisible(.Call(`_RMariaDB_connection_release`, con_))
}

connection_info <- function(con) {
  .Call(`_RMariaDB_connection_info`, con)
}

connection_quote_string <- function(con, xs) {
  .Call(`_RMariaDB_connection_quote_string`, con, xs)
}

connection_begin_transaction <- function(con) {
  invisible(.Call(`_RMariaDB_connection_begin_transaction`, con))
}

connection_commit <- function(con) {
  invisible(.Call(`_RMariaDB_connection_commit`, con))
}

connection_rollback <- function(con) {
  invisible(.Call(`_RMariaDB_connection_rollback`, con))
}

connection_is_transacting <- function(con) {
  .Call(`_RMariaDB_connection_is_transacting`, con)
}

driver_init <- function() {
  invisible(.Call(`_RMariaDB_driver_init`))
}

driver_done <- function() {
  invisible(.Call(`_RMariaDB_driver_done`))
}

version <- function() {
  .Call(`_RMariaDB_version`)
}

result_create <- function(con, sql, is_statement, immediate) {
  .Call(`_RMariaDB_result_create`, con, sql, is_statement, immediate)
}

result_release <- function(res) {
  invisible(.Call(`_RMariaDB_result_release`, res))
}

result_valid <- function(res_) {
  .Call(`_RMariaDB_result_valid`, res_)
}

result_fetch <- function(res, n) {
  .Call(`_RMariaDB_result_fetch`, res, n)
}

result_bind <- function(res, params) {
  invisible(.Call(`_RMariaDB_result_bind`, res, params))
}

result_has_completed <- function(res) {
  .Call(`_RMariaDB_result_has_completed`, res)
}

result_rows_fetched <- function(res) {
  .Call(`_RMariaDB_result_rows_fetched`, res)
}

result_rows_affected <- function(res) {
  .Call(`_RMariaDB_result_rows_affected`, res)
}

result_column_info <- function(res) {
  .Call(`_RMariaDB_result_column_info`, res)
}
